import 'dart:convert' as convert;
import 'package:dio/dio.dart';
import 'package:witsystem_core/aes/AES.dart';
import 'package:witsystem_core/config/WitsystemConfig.dart';
import 'package:witsystem_core/net/WitsystemNetConfig.dart';
import 'package:witsystem_core/rsa/RSA.dart';
import 'package:witsystem_core/util/StringUtil.dart';


class WitsystemNet {
  static final BaseOptions _options = BaseOptions(
    baseUrl: WitsystemNetConfig.host,
    connectTimeout: 1000 * 5,
    receiveTimeout: 1000 * 6,
    responseType: ResponseType.json,
  );

  static final Dio _dio = Dio(_options);

  ///验证签名的post 请求
  static authPost(String url, Map<String, dynamic> map) async {
    String nonceStr = StringUtil.getRandomString(16);
    int timeStamp = DateTime.now().millisecondsSinceEpoch;
    String body = convert.json.encode(map);
    String str = WitsystemConfig().appId +
        "\n" +
        WitsystemConfig().token +
        "\n" +
        timeStamp.toString() +
        "\n" +
        nonceStr +
        "\n" +
        body +
        "\n";
    _options.headers = {
      "appId": WitsystemConfig().appId,
      "token": WitsystemConfig().token,
      "sign": RSAUtil.sign(
          RSAUtil.creatdParseKey(WitsystemConfig().rsaParseKey), str),
      "nonceStr": nonceStr,
      "timeStamp": timeStamp,
    };
    _dio.options = _options;
    return await _ask(url, body);
  }

  ///不验证的请求
  static Future<Map<String, dynamic>> post(
      String url, Map<String, dynamic> map) async {
    _options.headers = null;
    _dio.options = _options;
    return await _ask(url, convert.json.encode(map));
  }

  ///统一的请求
  static Future<Map<String, dynamic>> _ask(String url, String body) async {
    try {
      Response response =
          await _dio.post<Map<String, dynamic>>(url, data: body);
      Map<String, dynamic> data = response.data;
      if (!data.containsKey("isEncryption") || !data["isEncryption"]) {
        return data;
      }

      String plainText =
          _handleCiphertext(data["encryptionType"], data["data"]);
      try {
        data.update("data", (value) => convert.json.decode(plainText));
      } catch (e) {
        data.update("data", (value) => plainText);
      }
      return data;
    } on DioError catch (e) {
      rethrow;
    }
  }

  ///处理密文
  static String _handleCiphertext(String encryptionType, String ciphertext) {
    switch (encryptionType.toUpperCase()) {
      case "AES":
        return AESUtil.decrypt(WitsystemConfig().appSecret, ciphertext);
      case "RSA":
        return RSAUtil.decrypt(
            RSAUtil.creatdParseKey(WitsystemConfig().rsaParseKey), ciphertext);
    }
    return "";
  }
}
