import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_core/generated/l10n.dart';

///自定义 dialog 弹出中间提示框
class DialogCenterHintWidget extends Dialog {
  final String title;
  final String content;
  final String? cancelText;
  final Color? cancelTextColor;
  final String? affirmText;
  final Color? affirmTextColor;
  final bool outSideDismissible; //点击窗户外是否关闭

  final Function(bool tag)? onPressed;

  ///tag 如果是true 代表点击确认
  const DialogCenterHintWidget(
      {Key? key,
      required this.title,
      this.outSideDismissible = false,
      this.cancelText,
      this.affirmText,
      this.cancelTextColor,
      this.affirmTextColor,
      required this.content,
      this.onPressed})
      : super(
            key: key, insetAnimationDuration: const Duration(milliseconds: 0));

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        if (outSideDismissible) Navigator.pop(context);
      },
      child: Container(
          height: double.infinity,
          width: double.infinity,
          color: Colors.black12,
          alignment: Alignment.center,
          child: Container(
            width: 300,
            margin: const EdgeInsets.fromLTRB(0, 0, 0, 100),
            decoration: const BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.all(Radius.circular(10)),
            ),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Padding(
                  padding: const EdgeInsets.all(10),
                  child: Text(
                    title,
                    style: const TextStyle(fontSize: 20),
                  ),
                ),
                Container(
                    padding: const EdgeInsets.fromLTRB(10, 0, 10, 15),
                    child: Text(content)),
                Container(
                    height: 1, width: double.maxFinite, color: Colors.black12),
                Row(
                  children: [
                    Expanded(
                      child: MaterialButton(
                        padding: const EdgeInsets.all(15),
                        minWidth: double.maxFinite,
                        shape: const RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                              bottomLeft: Radius.circular(10)),
                        ),
                        onPressed: () {
                          Navigator.pop(context);
                          if (onPressed != null) onPressed!(false);
                        },
                        child: Text(
                            cancelText == null
                                ? S.of(context).cancel
                                : cancelText!,
                            style: TextStyle(
                                color: cancelTextColor == null
                                    ? Colors.black
                                    : cancelTextColor!)),
                      ),
                    ),
                    Container(height: 40, width: 1, color: Colors.black12),
                    Expanded(
                      child: MaterialButton(
                        minWidth: double.maxFinite,
                        padding: const EdgeInsets.all(15),
                        shape: const RoundedRectangleBorder(
                          borderRadius: BorderRadius.only(
                              bottomRight: Radius.circular(10)),
                        ),
                        onPressed: () {
                          Navigator.pop(context);
                          if (onPressed != null) onPressed!(true);
                        },
                        child: Text(
                            affirmText == null
                                ? S.of(context).affirm
                                : affirmText!,
                            style: TextStyle(
                                color: affirmTextColor == null
                                    ? Colors.blue
                                    : affirmTextColor!)),
                      ),
                    ),
                  ],
                )
              ],
            ),
          )),
    );
  }
}
