import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_core/generated/l10n.dart';

/// 自定义dialog 弹出中间提示框，中间部分可以自定义
class DialogCenterInputWidget extends StatefulWidget {
  final String title;
  final String? contentHint;
  final String? cancelText;
  final Color? cancelTextColor;
  final String? affirmText;
  final Color? affirmTextColor;
  final bool outSideDismissible; //点击窗户外是否关闭

  final Function(bool tag, String text)? onPressed;

  ///tag 如果是true 代表点击确认
  const DialogCenterInputWidget(
      {Key? key,
      required this.title,
      this.outSideDismissible = false,
      this.cancelText,
      this.affirmText,
      this.cancelTextColor,
      this.affirmTextColor,
      this.contentHint,
      this.onPressed})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _DialogCenterInputWidgetState();
  }
}

class _DialogCenterInputWidgetState extends State<DialogCenterInputWidget> {
  final TextEditingController _controller = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black12,
      body: GestureDetector(
          onTap: () {
            if (widget.outSideDismissible) Navigator.pop(context);
          },
          child: Container(
              height: double.infinity,
              width: double.infinity,
              color: Colors.black12,
              alignment: Alignment.center,
              child: Container(
                width: 300,
                decoration: const BoxDecoration(
                  color: Colors.white,
                  borderRadius: BorderRadius.all(Radius.circular(10)),
                ),
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(10),
                      child: Text(
                        widget.title,
                        style: const TextStyle(fontSize: 20),
                      ),
                    ),
                    Container(
                        padding: const EdgeInsets.fromLTRB(10, 0, 10, 15),
                        child: TextField(
                          controller: _controller,
                          decoration: InputDecoration(
                            hintText: widget.contentHint,
                            hintStyle: const TextStyle(color: Colors.black26),
                          ),
                        )),
                    Container(
                        height: 1,
                        width: double.maxFinite,
                        color: Colors.black12),
                    Row(
                      children: [
                        Expanded(
                          child: MaterialButton(
                            padding: const EdgeInsets.all(15),
                            minWidth: double.maxFinite,
                            shape: const RoundedRectangleBorder(
                              borderRadius: BorderRadius.only(
                                  bottomLeft: Radius.circular(10)),
                            ),
                            onPressed: () {
                              Navigator.pop(context);
                              if (widget.onPressed != null) {
                                widget.onPressed!(false, _controller.text);
                              }
                            },
                            child: Text(
                              widget.cancelText == null
                                  ? S.of(context).cancel
                                  : widget.cancelText!,
                              style: TextStyle(
                                  color: widget.cancelTextColor == null
                                      ? Colors.black
                                      : widget.cancelTextColor!),
                            ),
                          ),
                        ),
                        Container(height: 40, width: 1, color: Colors.black12),
                        Expanded(
                          child: MaterialButton(
                            minWidth: double.maxFinite,
                            padding: const EdgeInsets.all(15),
                            shape: const RoundedRectangleBorder(
                              borderRadius: BorderRadius.only(
                                  bottomRight: Radius.circular(10)),
                            ),
                            onPressed: () {
                              Navigator.pop(context);
                              if (widget.onPressed != null) {
                                widget.onPressed!(true, _controller.text);
                              }
                            },
                            child: Text(
                                widget.affirmText == null
                                    ? S.of(context).affirm
                                    : widget.affirmText!,
                                style: TextStyle(
                                    color: widget.affirmTextColor == null
                                        ? Colors.blue
                                        : widget.affirmTextColor!)),
                          ),
                        ),
                      ],
                    )
                  ],
                ),
              ))),
    );
  }
}
