
import 'package:encrypt/encrypt.dart';
import 'package:pointycastle/asymmetric/api.dart';

///文档 https://pub.dev/packages/encrypt
class RSAUtil {
  ///字符串转成公钥
  static RSAPublicKey creatdPublicKey(String publicKeyString) {
    final parser = RSAKeyParser();
    return parser.parse(_handlerRsaKey(publicKeyString)) as RSAPublicKey;
  }

  ///字符串转成私钥
  static RSAPrivateKey creatdParseKey(String privateKeyString) {
    final parser = RSAKeyParser();
    return parser.parse(_handlerRsaKey(privateKeyString)) as RSAPrivateKey;
  }

  ///签名
  static String sign(RSAPrivateKey privateKey, String data) {
    var signer =
        Signer(RSASigner(RSASignDigest.SHA256, privateKey: privateKey));
    return signer.sign(data).base64;
  }

  ///加密
  static String encrypt(RSAPublicKey publicKey, String plainText) {
    final encrypter = Encrypter(RSA(publicKey: publicKey));
    return encrypter.encrypt(plainText).base64;
  }

  ///解密
  static String decrypt(RSAPrivateKey privateKey, String ciphertext) {
    final encrypter = Encrypter(RSA(privateKey: privateKey));
    return encrypter.decrypt64(ciphertext);
  }


  ///处理表示未分开的密钥
  static String _handlerRsaKey(String key) {
    if (key.contains("-----BEGIN RSA PUBLIC KEY-----")) {
      key = key.replaceAll(
          "-----BEGIN RSA PUBLIC KEY-----", "-----BEGIN RSA PUBLIC KEY-----\n");
      key = key.replaceAll(
          "-----END RSA PUBLIC KEY-----", "\n-----END RSA PUBLIC KEY-----");
    } else if (key.contains("-----BEGIN PUBLIC KEY-----")) {
      key.replaceAll(
          "-----BEGIN PUBLIC KEY-----", "-----BEGIN PUBLIC KEY-----\n");
      key = key.replaceAll(
          "-----END PUBLIC KEY-----", "\n-----END PUBLIC KEY-----");
    } else if (key.contains("-----BEGIN RSA PRIVATE KEY-----")) {
      key = key.replaceAll("-----BEGIN RSA PRIVATE KEY-----",
          "-----BEGIN RSA PRIVATE KEY-----\n");
      key = key.replaceAll(
          "-----END RSA PRIVATE KEY-----", "\n-----END RSA PRIVATE KEY-----");
    } else if (key.contains("-----BEGIN PRIVATE KEY-----")) {
      key = key.replaceAll(
          "-----BEGIN PRIVATE KEY-----", "-----BEGIN PRIVATE KEY-----\n");
      key = key.replaceAll(
          "-----END PRIVATE KEY-----", "\n-----END PRIVATE KEY-----");
    }

    return key;
  }




}
