import 'package:witsystem_core/aes/AES.dart';

import 'package:witsystem_core/cache/CacheManage.dart';
import 'package:witsystem_core/config/WitsystemConfig.dart';
import 'package:witsystem_core/net/WitsystemNet.dart';
import 'package:witsystem_core/user/LoginUserEntity.dart';
import 'dart:convert' as convert;
import '../util/StringUtil.dart';

///登陆用户的信息

class UserInfo {
  static const String _userKey = "witsystem_flutter_cache_user_key";

  static final UserInfo _instance = UserInfo._internal();

  LoginUserEntity? _loginUserEntity;

  factory UserInfo() {
    return _instance;
  }

  UserInfo._internal() {
    _readCacheLoginInfo();
  }

  ///用户密码登陆
  passwordLogin(String userId, String password) async {
    return _login(userId, password, "PASSWORD");
  }

  codeLogin(String userId, String code) async {
    return _login(userId, code, "CODE");
  }

  ///密码和验证密码的统一登陆
  /// checkCode 密码或者验证码
  _login(String userId, String checkCode, String loginType) async {
    var json = {
      "userId": userId,
      (loginType == "PASSWORD" ? "password" : "code"): checkCode,
      "appId": WitsystemConfig().appId,
      "platform": "APP",
      "appVersion": "1.0.0",
      "nonceStr": StringUtil.getRandomString(16),
      "timeStamp": DateTime.now().millisecondsSinceEpoch
    };
    var ciphertext =
        AESUtil.encrypt(WitsystemConfig().appSecret, convert.json.encode(json));
    Map<String, dynamic> map =
        await WitsystemNet.post("/user/user_login_safe", {
      "appId": WitsystemConfig().appId,
      "loginType": loginType,
      "ciphertext": ciphertext
    });
    _loginUserEntity = LoginUserEntity().fromJson(map["data"]);
    WitsystemConfig().token = _loginUserEntity!.token!;
    _cacheLoginInfo(map["data"]);
    return map;
  }

  ///缓存登陆信息
  _cacheLoginInfo(Map<String, dynamic> json) {
    CacheManage().setString(
        _userKey,
        AESUtil.encrypt(
            WitsystemConfig().appSecret, convert.json.encode(json)));
  }

  ///读取缓存数据
  _readCacheLoginInfo() {
    String? ciphertext = CacheManage().getString(_userKey);
    if (ciphertext == null) {
      return;
    }
    _loginUserEntity = LoginUserEntity().fromJson(convert.json
        .decode(AESUtil.decrypt(WitsystemConfig().appSecret, ciphertext)));
    WitsystemConfig().token = _loginUserEntity!.token!;
  }

  ///返回是否已经登陆
  bool isLogin() {
    return _loginUserEntity != null;
  }

  ///退出登陆
  logout() {
    CacheManage().remove(_userKey);
    _loginUserEntity = null;
    WitsystemConfig().token = "";
    WitsystemConfig().rsaParseKey = "";
  }

  ///返回用户信息
  LoginUserEntity? getUserInfo() {
    return _loginUserEntity;
  }
}
